django-productline
==================

an approach to feature-oriented software development(FOSD) of web application product lines based on django

The documentation is incomplete right now (work in progress): https://django-productline.readthedocs.org/

License: MIT
